@@ -87,8 +87,6 @@ MF1_single <- function(func_data, species_data = NULL, weight = 1, q = c(0,1,2))
       stop("Error: There exists NA values in species_data.")
   }
   
-  func_data[which(func_data==0,arr.ind = TRUE)]<-NA
-  
   if (is.vector(func_data)) func_data <- matrix(func_data,nrow=1)
   
   
@@ -246,8 +244,6 @@ MF2_multiple <- function(func_data, species_data = NULL, weight = 1, q = c(0,1,2
       stop("Error: There exists NA values in species_data.")
   }
   
-  func_data[which(func_data==0,arr.ind = TRUE)]<-NA
-  
   if (is.vector(func_data)) func_data <- matrix(func_data,nrow=1)
   
   
@@ -632,7 +628,7 @@ qMF_diversity <- function(w, v,q,tau=0.5,di=NULL,diversity="gamma"){
       1/N*exp(-sum(t(V)%*%Vv))
     }
     else {
-      Vv <- ifelse(is.na(v1),0,(v_plus/sum(V*(v%*%R)))^q)
+      Vv <- ifelse(v1==0,0,(v_plus/sum(V*(v%*%R)))^q)
       1/N*(sum(V*rowSums(Vv)))^(1/(1-q))
     }
   }
@@ -668,7 +664,7 @@ qMF_diversity <- function(w, v,q,tau=0.5,di=NULL,diversity="gamma"){
       1/N*exp(-sum(t(V)%*%Vv))
     }
     else {
-      Vv <- ifelse(is.na(v1) & ai==0,0,(ai/sum(V%*%ai))^q)
+      Vv <- ifelse(v1==0 & ai==0,0,(ai/sum(V%*%ai))^q)
       1/N*(sum(V*rowSums(Vv)))^(1/(1-q))
     }
   }
